@@ -24,6 +24,15 @@ def get_available_language(lang: str = None):
     return dict(key)
 
 
+def paste(content: str):
+    """
+    :param content: str
+    :return: {"link": link, "preview": link_preview}
+    """
+    r = requests.post(f"{BASE_URL}/paste", json={"content": content})
+    return r.json()
+
+
 kode = get_available_language()
 lang_flags = {
     "en": f"{emoji.FLAG_UNITED_STATES} English",
