@@ -1,14 +1,14 @@
 import requests
-from typing import Union
 from ._base_url import BASE_URL
 
 SUDO_URL = f"{BASE_URL}/sudos/"
 
 
-def get_sudos(chat_id: int) -> Union[list[int], int]:
+def get_sudos(chat_id: int):
     try:
         r = requests.get(f"{SUDO_URL}{chat_id}")
-        return r.json()["sudos"]
+        z: list[int] = r.json()["sudos"]
+        return z
     except KeyError:
         return 404
 
